==> gene2pathway_2.2.0.tar.gz: gene2pathway/R/retrain.R <==
# 1. train codes
# 2. used codes to train structure
trainall = function(traindat){
	y = traindat$labels
	x = traindat$features
	ytmp = y
	ytmp[ytmp == 0] = -1	
	codes = gene2pathway:::code_train(x, ytmp, traindat$kegg_hierarchy$parentsLev1, traindat$kegg_hierarchy$parentsLev2, traindat$kegg_hierarchy$parentsLev12)	
	# fit model at all hierarchy levels
	fit = gene2pathway:::struct_train(codes$code, y, traindat$treesizes, traindat$kegg_hierarchy$parentPaths)
	model = list(W=fit$W, C=fit$C, detectors=codes$detectors, used_domains=codes$domains, alldomains=colnames(x), allpathways=colnames(fit$C), treesizes=traindat$treesizes, kegg_hierarchy=traindat$kegg_hierarchy, elemIDs=traindat$elemIDs)
	class(model) = "model"
	model
}

# bagging
trainallBag = function(traindat, nbag=11, stratified=FALSE, mc.cores=8){
	y = traindat$labels
	if ("doMC" %in% loadedNamespaces()){
		registerDoMC(mc.cores)		
		model = foreach(b=1:nbag) %dopar% {
					if(!stratified)
						boot = sample(1:nrow(y), nrow(y), replace=TRUE)
					else{
						boot = c()
						for(i in 1:ncol(y))
							boot = c(boot, base:::sample(which(y[,i] == 1), replace=TRUE))
						boot = unique(boot)					
					}					
					tmp = traindat
					tmp$labels = traindat$labels[boot,]				
					tmp$features = traindat$features[boot,]
					gene2pathway:::trainall(tmp)				
				}
	}
	else{
		model = list()
		for(b in 1:nbag){
			if(!stratified)
				boot = sample(1:nrow(y), nrow(y), replace=TRUE)
			else{
				boot = c()
				for(i in 1:ncol(y))
					boot = c(boot, base:::sample(which(y[,i] == 1), replace=TRUE))
				boot = unique(boot)					
			}					
			tmp = traindat
			tmp$labels = traindat$labels[boot,]				
			tmp$features = traindat$features[boot,]
			model[[b]] = gene2pathway:::trainall(tmp)				
		}
	}
	if(length(model) == nbag & all(sapply(model, length) == 9))
		cat("model ok\n")
	else
		stop("Problem during model training occured. Model is corrupt.\n")
	model
}

retrain = function(minnmap=30, level1Only="Metabolism", level2Only="Genetic Information Processing", organism="hsa", gene2Domains=NULL, remove.duplicates=FALSE, use.bagging=TRUE, nbag=11, mc.cores=8){	
	traindat = gene2pathway:::buildTrainingSet(minnmap=minnmap, level1Only=level1Only, level2Only=level2Only, organism=organism, remove.duplicates=remove.duplicates, gene2Domains=gene2Domains)	
	if(use.bagging)
		modelKEGG = gene2pathway:::trainallBag(traindat, nbag=nbag, mc.cores=mc.cores)
	else
		modelKEGG = gene2pathway:::trainall(traindat)	
	save(modelKEGG, file=paste("classificationModel_", organism,".rda",sep=""))
	modelKEGG
}

retrain.signaltrans = function(minnmap=15, organism="hsa", gene2Domains=NULL, remove.duplicates=FALSE, use.bagging=TRUE, nbag=11, mc.cores=8){	
	traindat = gene2pathway:::buildTrainingSet.signaltrans(minnmap=minnmap, remove.duplicates=remove.duplicates, organism=organism, gene2Domains=gene2Domains)
	if(use.bagging)
		modelSignalTrans = gene2pathway:::trainallBag(traindat, mc.cores=mc.cores)
	else
		modelSignalTrans = gene2pathway:::trainall(traindat)		
	save(modelSignalTrans, file=paste("classificationModelSignalTrans_",organism,".rda",sep=""))
	modelSignalTrans
}

==> gene2pathway_2.12.0.tar.gz: gene2pathway/R/retrain.R <==
# 1. train codes
# 2. used codes to train structure
trainall = function(traindat){
	y = traindat$labels
	x = traindat$features
	ytmp = y
	ytmp[ytmp == 0] = -1	
	codes = gene2pathway:::code_train(x, ytmp, traindat$kegg_hierarchy$parentsLev1, traindat$kegg_hierarchy$parentsLev2, traindat$kegg_hierarchy$parentsLev12)	
	# fit model at all hierarchy levels
	fit = gene2pathway:::struct_train(codes$code, y, traindat$treesizes, traindat$kegg_hierarchy$parentPaths)
	model = list(W=fit$W, C=fit$C, detectors=codes$detectors, used_domains=codes$domains, alldomains=colnames(x), allpathways=colnames(fit$C), treesizes=traindat$treesizes, kegg_hierarchy=traindat$kegg_hierarchy, elemIDs=traindat$elemIDs)
	class(model) = "model"
	model
}

# bagging
trainallBag = function(traindat, nbag=11, stratified=FALSE, mc.cores=8){
	y = traindat$labels
	if ("doMC" %in% loadedNamespaces()){
		registerDoMC(mc.cores)		
		model = foreach(b=1:nbag) %dopar% {
					if(!stratified)
						boot = sample(1:nrow(y), nrow(y), replace=TRUE)
					else{
						boot = c()
						for(i in 1:ncol(y))
							boot = c(boot, base:::sample(which(y[,i] == 1), replace=TRUE))
						boot = unique(boot)					
					}					
					tmp = traindat
					tmp$labels = traindat$labels[boot,]				
					tmp$features = traindat$features[boot,]
					gene2pathway:::trainall(tmp)				
				}
	}
	else{
		model = list()
		for(b in 1:nbag){
			if(!stratified)
				boot = sample(1:nrow(y), nrow(y), replace=TRUE)
			else{
				boot = c()
				for(i in 1:ncol(y))
					boot = c(boot, base:::sample(which(y[,i] == 1), replace=TRUE))
				boot = unique(boot)					
			}					
			tmp = traindat
			tmp$labels = traindat$labels[boot,]				
			tmp$features = traindat$features[boot,]
			model[[b]] = gene2pathway:::trainall(tmp)				
		}
	}
	if(length(model) == nbag & all(sapply(model, length) == 9))
		cat("model ok\n")
	else
		stop("Problem during model training occured. Model is corrupt.\n")
	model
}

retrain = function(minnmap=30, level1Only="Metabolism", level2Only="Genetic Information Processing", organism="hsa", gene2Domains=NULL, remove.duplicates=FALSE, use.bagging=TRUE, nbag=11, mc.cores=8){	
	traindat = gene2pathway:::buildTrainingSet(minnmap=minnmap, level1Only=level1Only, level2Only=level2Only, organism=organism, remove.duplicates=remove.duplicates, gene2Domains=gene2Domains)	
	if(use.bagging)
		modelKEGG = gene2pathway:::trainallBag(traindat, nbag=nbag, mc.cores=mc.cores)
	else
		modelKEGG = gene2pathway:::trainall(traindat)	
	save(modelKEGG, file=paste("classificationModel_", organism,".rda",sep=""))
	modelKEGG
}

retrain.signaltrans = function(minnmap=15, organism="hsa", gene2Domains=NULL, branch="Signal Transduction", remove.duplicates=FALSE, use.bagging=TRUE, nbag=11, mc.cores=8){	
	traindat = gene2pathway:::buildTrainingSet.signaltrans(minnmap=minnmap, remove.duplicates=remove.duplicates, organism=organism, gene2Domains=gene2Domains, branch=branch)
	if(use.bagging)
		modelSignalTrans = gene2pathway:::trainallBag(traindat, mc.cores=mc.cores)
	else
		modelSignalTrans = gene2pathway:::trainall(traindat)		
	save(modelSignalTrans, file=paste("classificationModelSignalTrans_",organism,".rda",sep=""))
	modelSignalTrans
}
